'use strict';

var path = require('path');
var fs = require('fs');
var JSON5 = require('json5');

var INFINITY = 1 / 0;
var BABELRC_FILENAME = '.babelrc';
var PACKAGE_FILENAME = 'package.json';

module.exports = function findBabelConfig(start) {
    var depth = arguments.length <= 1 || arguments[1] === undefined ? INFINITY : arguments[1];

    if (!start) {
        return null;
    }

    var dir = path.isAbsolute(start) ? start : path.join(process.cwd(), start);
    var loopLeft = depth;

    // eslint-disable-next-line no-cond-assign
    do {
        var babelrc = path.join(dir, BABELRC_FILENAME);
        if (fs.existsSync(babelrc)) {
            var babelrcContent = fs.readFileSync(babelrc, 'utf8');
            return {
                file: babelrc,
                config: JSON5.parse(babelrcContent)
            };
        }

        var packageFile = path.join(dir, PACKAGE_FILENAME);
        if (fs.existsSync(packageFile)) {
            var packageContent = fs.readFileSync(packageFile, 'utf8');
            var packageJson = JSON.parse(packageContent);
            if (packageJson.babel) {
                return {
                    file: packageFile,
                    config: packageJson.babel
                };
            }
        }

        if (loopLeft-- === 0) {
            return null;
        }
    } while (dir !== (dir = path.dirname(dir)));

    return null;
};